package com.fs.qw.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.fs.qw.domain.FsCompanyCustomerLog;

import java.util.List;

/**
 * 客户信息认领记录Service接口
 * 
 * @author ruoyi
 */
public interface IFsCompanyCustomerLogService extends IService<FsCompanyCustomerLog> {

    /**
     * 查询客户信息认领记录
     * 
     * @param id 主键
     * @return 记录
     */
    public FsCompanyCustomerLog selectFsCompanyCustomerLogById(Long id);

    /**
     * 查询客户信息认领记录列表
     * 
     * @param fsCompanyCustomerLog 查询条件
     * @return 记录集合
     */
    public List<FsCompanyCustomerLog> selectFsCompanyCustomerLogList(FsCompanyCustomerLog fsCompanyCustomerLog);

    /**
     * 根据客户信息表主键查询
     * @param companyCustomerId 客户信息表主键
     * @return  返回该客户信息表下的所有认领记录
     */
    List<FsCompanyCustomerLog> selectFsCompanyCustomerLogByCustomerId(Long companyCustomerId);

    /**
     * 新增客户信息认领记录
     * 
     * @param fsCompanyCustomerLog 记录
     * @return 结果
     */
    public int insertFsCompanyCustomerLog(FsCompanyCustomerLog fsCompanyCustomerLog);

    /**
     * 修改客户信息认领记录
     * 
     * @param fsCompanyCustomerLog 记录
     * @return 结果
     */
    public int updateFsCompanyCustomerLog(FsCompanyCustomerLog fsCompanyCustomerLog);

    /**
     * 批量删除客户信息认领记录
     * 
     * @param ids 需要删除的主键集合
     * @return 结果
     */
    public int deleteFsCompanyCustomerLogByIds(Long[] ids);

    /**
     * 删除客户信息认领记录信息
     * 
     * @param id 主键
     * @return 结果
     */
    public int deleteFsCompanyCustomerLogById(Long id);
}